# Changelog

## 0.1.2

- Fix focus() to accept logger name and return Logger instance

## 0.1.1

- Add project URLs to pyproject.toml

## 0.1.0 (2026-03-10)

- Initial release
- Color-coded log levels with ANSI codes
- Repeat message suppression
- Slow operation highlighting
- Drop-in logging.Handler replacement
